polyfemos.front.alertreader — polyfemos 0.3.29 documentation

# polyfemos.front.alertreader

Functions for reading state of health alert files (‘*.alert’)

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.front.alertreader.` `get_sohdict`(station_ids, year, julday, fpf, realtimeness=None)

  Reads state of health alert (‘*.alert’) files. Extracts the data for all `station_ids`, if available. The date of the alert file is defined by `year` and `julday` (day of the year).

  Parameters

    - station_ids (list) – A list of string consisting of station codes together with network code, for example “FN.MSF”

    - year (numlike) –

    - julday (numlike) –

    - fpf (func) – filepath format leading to an alert file

    - realtimeness (`UTCDateTime` or int or float or None) – Defaults to `None`. If proper `realtimeness` is given, alerts with the last datapoint timevalue lesser than `realtimeness`, are changed to `"nan"`

  Return type

    dict

  Returns

    A dictionary consisting of ‘alerts’ and ‘priorities’ dictionaries with each station and sohpar combination